# Nomenclature

## Acronyms

| Acronym | Meaning |
|---------|---------|
| CIRA86 | COSPAR International Reference Atmosphere (1986) |
| LTC | Low-Temperature Correction (Sutherland viscosity model) |
| ODE | Ordinary Differential Equation |
| USSA76 | US Standard Atmosphere (1976) |

## Latin Symbols

| Symbol | Description | Units |
|--------|-------------|-------|
| $a$ | Speed of sound, $a = \sqrt{\gamma R T}$ | m s⁻¹ |
| $c_p$ | Specific heat at constant pressure | J kg⁻¹ K⁻¹ |
| $c_v$ | Specific heat at constant volume | J kg⁻¹ K⁻¹ |
| $g_0$ | Standard gravity (9.80665 m s⁻²) | m s⁻² |
| $h$ | Geometric altitude | m |
| $L$ | Reference length | m |
| $M$ | Mach number, $M = U / a$ | — |
| $p$ | Static pressure | Pa |
| $R$ | Specific gas constant, $R = R_u / \mathcal{M}$ | J kg⁻¹ K⁻¹ |
| $R_u$ | Universal gas constant (8314 J kmol⁻¹ K⁻¹) | J kmol⁻¹ K⁻¹ |
| $\mathrm{Re}_1$ | Unit Reynolds number, $\rho U / \mu$ | m⁻¹ |
| $\mathrm{Re}_L$ | Reynolds number based on length $L$ | — |
| $S$ | Sutherland constant | K |
| $T$ | Static temperature | K |
| $U$ | Flow velocity | m s⁻¹ |
| $Z$ | Compressibility factor (equilibrium air) | — |

## Greek Symbols

| Symbol | Description | Units |
|--------|-------------|-------|
| $\gamma$ | Ratio of specific heats, $c_p / c_v$ | — |
| $\lambda$ | Atmospheric temperature lapse rate | K km⁻¹ |
| $\mathcal{M}$ | Molar mass | kg kmol⁻¹ |
| $\mu$ | Dynamic viscosity | Pa s |
| $\rho$ | Density | kg m⁻³ |
| $\theta_\text{vib}$ | Characteristic vibrational temperature | K |

## Subscripts and Superscripts

| Symbol | Meaning |
|--------|---------|
| $(\cdot)_0$ | Stagnation (total) condition |
| $(\cdot)_b$ | Base-layer value (atmosphere layer equations) |
| $(\cdot)_\text{eff}$ | Effective value (real-gas mixture) |
| $(\cdot)_\text{ref}$ | Reference value (Sutherland model) |
| $(\cdot)_\text{rot}$ | Rotational energy mode |
| $(\cdot)_\text{trans}$ | Translational energy mode |
| $(\cdot)_\text{vib}$ | Vibrational energy mode |
